pub enum Node {
Text(String),
OpenSection(&'static str),
CloseSection,
Newline,
}
Formats the value using the given formatter. Read more
Performs copy-assignment from source. Read more
A node is rendered by adding itself to the document
Produce a new Document with self added to the into Document.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
Produce a new Document with self added to the into Document.