ColorArg

Struct ColorArg 

pub struct ColorArg(pub ColorChoice);
A command line argument that configures the coloring of the output

This can be used with command line argument parsers like clap or structopt.

Example

extern crate language_reporting;
#[macro_use]
extern crate structopt;

use structopt::StructOpt;
use termcolor::StandardStream;
use language_reporting::ColorArg;

#[derive(Debug, StructOpt)]
#[structopt(name = "groovey-app")]
pub struct Opts {
    /// Configure coloring of output
    #[structopt(
        long = "color",
        parse(try_from_str),
        default_value = "auto",
        raw(possible_values = "ColorArg::VARIANTS", case_insensitive = "true")
    )]
    pub color: ColorArg,
}

fn main() {
    let opts = Opts::from_args();
    let writer = StandardStream::stderr(opts.color.into());
}

Tuple Fields

0: ColorChoice

Implementations

Source

impl ColorArg

pub const VARIANTS: &'static [&'static str]

Allowed values the argument

This is useful for generating documentation via clap or structopt’s possible_values configuration.