[−][src]Struct language_reporting::Document
The Document is the root node in a render tree.
The tree! macro produces a Document, and you can also build
one manually.
use render_tree::prelude::*; use render_tree::Render; fn main() -> std::io::Result<()> { let document = Document::empty() // You can add a `Line` to a document, with nested content .add(Line( // Strings implement `Render` "Hello" )) .add(Line( 1.add(".").add(10) )) .add(Section("code", |doc| doc.add("[E").add(1000).add("]") )); assert_eq!(document.to_string()?, "Hello\n1.10\n[E1000]"); Ok(()) }
The above example is equivalent to this use of the tree! macro:
#[macro_use] extern crate render_tree; use render_tree::prelude::*; fn main() -> std::io::Result<()> { let document = tree! { <Line as { "Hello" }> <Line as { {1} "." {10} }> <Section name="code" as { "[E" {1000} "]" }> }; assert_eq!(document.to_string()?, "Hello\n1.10\n[E1000]"); Ok(()) }
Methods
impl Document[src]
pub fn debug_write<impl WriteColor>(
&self,
writer: &mut impl WriteColor,
stylesheet: &Stylesheet
) -> Result<(), Error> where
impl WriteColor: WriteColor, [src]
&self,
writer: &mut impl WriteColor,
stylesheet: &Stylesheet
) -> Result<(), Error> where
impl WriteColor: WriteColor,
impl Document[src]
pub fn empty() -> Document[src]
pub fn with<impl Render>(renderable: impl Render) -> Document where
impl Render: Render, [src]
impl Render: Render,
pub fn add<impl Render>(self, renderable: impl Render) -> Document where
impl Render: Render, [src]
impl Render: Render,
pub fn write(self) -> Result<(), Error>[src]
pub fn to_string(self) -> Result<String, Error>[src]
pub fn write_styled(self, stylesheet: &Stylesheet) -> Result<(), Error>[src]
pub fn write_with<impl WriteColor>(
self,
writer: &mut impl WriteColor,
stylesheet: &Stylesheet
) -> Result<(), Error> where
impl WriteColor: WriteColor, [src]
self,
writer: &mut impl WriteColor,
stylesheet: &Stylesheet
) -> Result<(), Error> where
impl WriteColor: WriteColor,