[−][src]Struct language_reporting::Label
A label describing an underlined region of code associated with a diagnostic
Fields
span: SpanThe span we are going to include in the final snippet.
message: Option<String>A message to provide some additional information for the underlined code.
style: LabelStyleThe style to use for the label.
Methods
impl<Span: ReportingSpan> Label<Span>[src]
impl<Span: ReportingSpan> Label<Span>pub fn new(span: Span, style: LabelStyle) -> Label<Span> | [src] |
pub fn new_primary(span: Span) -> Label<Span> | [src] |
pub fn new_secondary(span: Span) -> Label<Span> | [src] |
pub fn with_message<S: Into<String>>(self, message: S) -> Label<Span> | [src] |
pub fn message(&self) -> &Option<String> | [src] |