[−][src]Struct language_reporting::SimpleSpan
Methods
impl SimpleSpan[src]
impl SimpleSpanTrait Implementations
impl ReportingSpan for SimpleSpan[src]
impl ReportingSpan for SimpleSpanfn with_start(&self, start: usize) -> Self | [src] |
fn with_end(&self, end: usize) -> Self | [src] |
fn start(&self) -> usize | [src] |
fn end(&self) -> usize | [src] |
impl Clone for SimpleSpan[src]
impl Clone for SimpleSpanfn clone(&self) -> SimpleSpan | [src] |
fn clone_from(&mut self, source: &Self) | 1.0.0 [src] |
Performs copy-assignment from source. Read more
impl Copy for SimpleSpan[src]
impl Copy for SimpleSpanimpl Debug for SimpleSpan[src]
impl Debug for SimpleSpanAuto Trait Implementations
impl Send for SimpleSpan
impl Send for SimpleSpanimpl Sync for SimpleSpan
impl Sync for SimpleSpanBlanket Implementations
impl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T> ToOwned for T where
T: Clone, [src]
impl<T> ToOwned for T where
T: Clone, impl<T> From for T[src]
impl<T> From for Timpl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error> | [src] |
impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId | [src] |
impl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error> | [src] |
impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, fn borrow_mut(&mut self) -> &mut T | [src] |